# spbessax

This repository contains a JAX implementation of spherical bessel functions that
is full compatible with jax.jit and jax.grad. It is based on the implementation
by @sousaw in [NeuralIL][https://github.com/Madsen-s-research-group/neuralil-public-releases].
